@@ -3,7 +3,7 @@ package class::with::roles;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-06-05'; # DATE
 our $DIST = 'class-with-roles'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 #use warnings;
@@ -19,7 +19,7 @@ sub import {
     }
     (my $class_pm = "$class.pm") =~ s!::!/!g;
     require $class_pm;
-    $class_pm->import(@class_import_args);
+    $class->import(@class_import_args);
 
     my @roles;
     while (@_) {
@@ -52,7 +52,7 @@ class::with::roles - Shortcut for using a class and applying it some Role::Tiny
 
 =head1 VERSION
 
-This document describes version 0.002 of class::with::roles (from Perl distribution class-with-roles), released on 2020-06-05.
+This document describes version 0.003 of class::with::roles (from Perl distribution class-with-roles), released on 2020-06-05.
 
 =head1 SYNOPSIS
 
